@@ -210,19 +210,19 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
         //others)
         QVariantMap properties = reply.argumentAt<0>();
         QString path = properties["IconThemePath"].toString();
-        if (!path.isEmpty() && path != data()["IconThemePath"].toString()) {
-            // FIXME: If last part of path is not "icons", this won't work!
-            QStringList tokens = path.split('/', QString::SkipEmptyParts);
-            if (tokens.length() >= 3 && tokens.takeLast() == "icons") {
-                QString appName = tokens.takeLast();
 
-                if (!m_customIconLoader) {
-                    m_customIconLoader = new KIconLoader(appName, QStringList(), this);
-                }
-                m_customIconLoader->addAppDir(appName, path);
-            } else {
-                qWarning() << "Wrong IconThemePath" << path << ": too short or does not end with 'icons'";
+        if (!path.isEmpty() && path != data()["IconThemePath"].toString()) {
+            if (!m_customIconLoader) {
+                m_customIconLoader = new KIconLoader(QString(), QStringList(), this);
             }
+
+            //icons may be either in the root directory of the passed path or in a appdir format
+            //i.e hicolor/32x32/iconname.png
+
+            m_customIconLoader->reconfigure(QString(), QStringList(path));
+
+            //add app dir requires an app name, though this is completely unused in this context
+            m_customIconLoader->addAppDir(QString("unused"), path);
         }
         setData("IconThemePath", path);
 
