@@ -30,7 +30,7 @@
 #include <kwindowsystem.h>
 #include <klocalizedstring.h>
 
-#include <Plasma/Package>
+#include <KPackage/Package>
 
 DesktopView::DesktopView(Plasma::Corona *corona, QScreen *targetScreen)
     : PlasmaQuick::View(corona, 0),
@@ -41,10 +41,10 @@ DesktopView::DesktopView(Plasma::Corona *corona, QScreen *targetScreen)
         setScreen(targetScreen);
     }
 
-    setTitle(corona->package().metadata().name());
-    setIcon(QIcon::fromTheme(corona->package().metadata().icon()));
+    setTitle(corona->kPackage().metadata().name());
+    setIcon(QIcon::fromTheme(corona->kPackage().metadata().iconName()));
     engine()->rootContext()->setContextProperty("desktop", this);
-    setSource(QUrl::fromLocalFile(corona->package().filePath("views", "Desktop.qml")));
+    setSource(QUrl::fromLocalFile(corona->kPackage().filePath("views", "Desktop.qml")));
 
     ensureWindowType();
     adaptToScreen();
@@ -52,7 +52,7 @@ DesktopView::DesktopView(Plasma::Corona *corona, QScreen *targetScreen)
     //For some reason, if I connect the method directly it doesn't get called, I think it's for the lack of argument
     connect(this, &QWindow::screenChanged, this, [=](QScreen*) { adaptToScreen(); ensureWindowType(); });
 
-    QObject::connect(corona, &Plasma::Corona::packageChanged,
+    QObject::connect(corona, &Plasma::Corona::kPackageChanged,
                      this, &DesktopView::coronaPackageChanged);
 
     connect(this, &DesktopView::sceneGraphInitialized, this,
@@ -90,11 +90,17 @@ void DesktopView::adaptToScreen()
         setMinimumSize(screen()->geometry().size());
         setMaximumSize(screen()->geometry().size());
 
-        if(m_oldScreen)
-            disconnect(m_oldScreen.data(), &QScreen::geometryChanged, this, static_cast<void (QWindow::*)(const QRect&)>(&QWindow::setGeometry));
-        connect(screen(), &QScreen::geometryChanged, this, static_cast<void (QWindow::*)(const QRect&)>(&QWindow::setGeometry), Qt::UniqueConnection);
+        if(m_oldScreen) {
+            disconnect(m_oldScreen.data(), &QScreen::geometryChanged,
+                       this, &DesktopView::screenGeometryChanged);
+        }
+
+        connect(screen(), &QScreen::geometryChanged,
+                this, &DesktopView::screenGeometryChanged, Qt::UniqueConnection);
+
     } else {
-        disconnect(screen(), &QScreen::geometryChanged, this, static_cast<void (QWindow::*)(const QRect&)>(&QWindow::setGeometry));
+        disconnect(screen(), &QScreen::geometryChanged,
+                   this, &DesktopView::screenGeometryChanged);
     }
 
     m_oldScreen = screen();
@@ -148,6 +154,15 @@ void DesktopView::ensureWindowType()
     }
 }
 
+DesktopView::SessionType DesktopView::sessionType() const
+{
+    if (qobject_cast<ShellCorona *>(corona())) {
+        return ShellSession;
+    } else {
+        return ApplicationSession;
+    }
+}
+
 void DesktopView::setDashboardShown(bool shown)
 {
     if (shown) {
@@ -225,8 +240,13 @@ bool DesktopView::isDashboardShown() const
 void DesktopView::showConfigurationInterface(Plasma::Applet *applet)
 {
     if (m_configView) {
-        m_configView.data()->hide();
-        m_configView.data()->deleteLater();
+        if (m_configView->applet() != applet) {
+            m_configView->hide();
+            m_configView->deleteLater();
+        } else {
+            m_configView->requestActivate();
+            return;
+        }
     }
 
     if (!applet || !applet->containment()) {
@@ -244,27 +264,16 @@ void DesktopView::showConfigurationInterface(Plasma::Applet *applet)
     m_configView.data()->show();
 }
 
-void DesktopView::coronaPackageChanged(const Plasma::Package &package)
+void DesktopView::screenGeometryChanged(const QRect &geom)
+{
+    setGeometry(screen()->geometry());
+    setMinimumSize(screen()->geometry().size());
+    setMaximumSize(screen()->geometry().size());
+}
+
+
+void DesktopView::coronaPackageChanged(const KPackage::Package &package)
 {
     setContainment(0);
     setSource(QUrl::fromLocalFile(package.filePath("views", "Desktop.qml")));
 }
-
-void DesktopView::screenDestroyed(QObject* screen)
-{
-//     NOTE: this is overriding the screen destroyed slot, we need to do this because
-//     otherwise Qt goes mental and starts moving our panels. See:
-//     https://codereview.qt-project.org/#/c/88351/
-//     Also note this isnt' called anymore after Qt 5.4, because now it's using a compile-time connect
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0))
-#   warning Remove method once depending on Qt 5.4
-#endif
-    if (screen == this->screen()) {
-        ShellCorona *c = qobject_cast<ShellCorona *>(corona());
-        if (c) {
-            c->remove(this);
-        }
-    }
-}
-
-#include "moc_desktopview.cpp"
